Name:       voxelands
Version:    1604.00
Release:    1%{?dist}
Summary:    The Fun-Focused Free Software Voxel World Game

# bundled(jthread) uses MIT
License:    GPLv3 and MIT and CC-BY-SA
URL:        http://www.voxelands.com
Source0:    http://www.voxelands.com/downloads/%{name}-%{version}-src.tar.bz2
Source1:    %{name}@.service
Source2:    default.conf
Source3:    %{name}.README
Source4:    %{name}.rsyslog
Source5:    %{name}.logrotate
Patch0:    %{name}-cmake.patch
# patch until next release
Patch1:    %{name}-jthread.patch

# same reason as: https://fedorahosted.org/fpc/ticket/347
Provides: bundled(jthread) = 1.0
BuildRequires:  cmake >= 2.6.0
BuildRequires:  irrlicht-devel
BuildRequires:  bzip2-devel gettext-devel
BuildRequires:  sqlite-devel
BuildRequires:  libpng-devel
BuildRequires:  libjpeg-turbo-devel
BuildRequires:  libXxf86vm-devel
BuildRequires:  mesa-libGL-devel
BuildRequires:  openal-soft-devel
BuildRequires:  libvorbis-devel
BuildRequires:  libogg-devel
BuildRequires:  desktop-file-utils
BuildRequires:  freetype-devel

Requires: hicolor-icon-theme

%description
Voxelands is a sandbox construction game based on Minetest, which was inspired by
rlier "voxel world" games such as Infiniminer. Gameplay puts players in a fully
destructible 3D game world where they can place and dig numerous types of blocks,
items and creatures using a variety of tools. Inside the game world players can
build structures, artworks and anything else their creativity can think of on
multiplayer servers and singleplayer worlds across multiple game modes.

%package server
Summary: Voxelands multiplayer server

Requires(pre): shadow-utils
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description server
Voxelands multiplayer server. This package does not require X Windows System.

%prep
%setup -q -n %{name}
%patch0 -p1
%patch1 -p1

%build
# RUN_IN_PLACE gets configuration from project source directory
# bundled(jthread) is being linked from project source if
# -DBUILD_SHARED_LIBS:BOOL=ON (which is default behaviour)
# %%cmake -DBUILD_SHARED_LIBS=OFF \
%cmake -DRUN_IN_PLACE=0 .
make %{?_smp_mflags}


%install
%make_install

# add desktop file
desktop-file-install --dir=%{buildroot}%{_datadir}/applications misc/freedesktop/%{name}.desktop

# Systemd unit file
mkdir -p %{buildroot}%{_unitdir}/
install -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}

# /etc/rsyslog.d/voxelands.conf
mkdir -p %{buildroot}%{_sysconfdir}/rsyslog.d/
install -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/rsyslog.d/%{name}.conf

# /etc/logrotate.d/voxelands
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
install -m 0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-server

# /var/lib/voxelands directory for server data files
install -d -m 0775 %{buildroot}%{_sharedstatedir}/%{name}/
install -d -m 0775 %{buildroot}%{_sharedstatedir}/%{name}/default/

# /etc/voxelands/default.conf
install -d -m 0775 %{buildroot}%{_sysconfdir}/%{name}/
install    -m 0664 %{name}.conf.example %{buildroot}%{_sysconfdir}/%{name}/default.conf

# /etc/sysconfig/default.conf
install -d -m 0775 %{buildroot}%{_sysconfdir}/sysconfig/%{name}/
install    -m 0664 %{SOURCE2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}

cp -p %{SOURCE3} README.fedora

# Move doc directory back to the sources
mkdir __doc
mv  %{buildroot}%{_datadir}/doc/%{name}/* __doc
rm -rf %{buildroot}%{_datadir}/doc/%{name}


%find_lang %{name}

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%pre server
getent group %{name} >/dev/null || groupadd -r %{name}
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_sharedstatedir}/%{name} -s /sbin/nologin \
    -c "Voxelands Multiplayer Server" %{name}
exit 0

%post server
%systemd_post %{name}@default.service

%preun server
%systemd_preun %{name}@default.service

%postun server
%systemd_postun_with_restart %{name}@default.service


%files
%license doc/gpl-3.0.txt src/jthread/LICENSE.MIT
%doc README.fedora
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/16x16/apps/%{name}.png
%{_datadir}/icons/hicolor/192x192/apps/%{name}.png
%{_datadir}/icons/hicolor/22x22/apps/%{name}.png
%{_datadir}/icons/hicolor/24x24/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/48x48/apps/%{name}.png
%{_datadir}/icons/hicolor/64x64/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man6/voxelands.*
%{_datadir}/appdata/%%{name}.appdata.xml

%files server
%license doc/gpl-3.0.txt src/jthread/LICENSE.MIT
%doc doc/changelog.txt doc/mapformat.txt doc/protocol.txt README.fedora voxelands.conf.example
%{_bindir}/%{name}-server
%{_datadir}/%{name}
%{_unitdir}/%{name}@.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-server
%config(noreplace) %{_sysconfdir}/rsyslog.d/%{name}.conf
%attr(-,voxelands,voxelands)%{_sharedstatedir}/%{name}/
%attr(-,voxelands,voxelands)%{_sysconfdir}/%{name}/
%attr(-,voxelands,voxelands)%{_sysconfdir}/sysconfig/%{name}
%{_mandir}/man6/voxelands-server.*


%changelog
* Sat Apr 30 2016 Ye Myat Kaung <mavjs01@gmail.com> - 1604.00-1
- voxelands 1604.00 release

* Sat Feb 27 2016 Ye Myat Kaung <mavjs01@gmail.com> - 1602.00-1
- voxelands 1602.00 stable release

* Sun Dec 27 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1512.00-1
- voxelands 1512.00 stable release

* Mon Sep 07 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1508.01-1
- voxelands 1508.01 stable release

* Tue Aug 04 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1507.00-2
- rebuilt as the C++11 compatibilities broke game

* Fri Jul 31 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1507.00-1
- voxelands 1507.00 stable release

* Sat Jun 20 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1506.00-1
- voxelands 1506.00 stable release

* Thu Jun 18 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1505.01-1
- voxelands 1505.01 stable release

* Thu Apr 30 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1504.01-1
- voxelands 1504.01 stable release

* Sun Apr 26 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1504.00-1
- voxelands 1504.00 stable release

* Thu Mar 26 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1503.01-1
- voxelands 1503.01 stable release

* Sat Jan 31 2015 Ye Myat Kaung <mavjs01@gmail.com> - 1501.00-1
- voxelands 1501.00 stable release

* Tue Dec 23 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1412.01-1
- voxelands 1412.01 stable release

* Wed Nov 19 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1411.03-1
- voxelands 1411.03 stable release

* Sat Nov 15 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1411.02-1
- voxelands 1411.02 stable release

* Sat Nov 15 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1411.01-2
- enable freetype support

* Sat Nov 15 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1411.01-1
- voxelands 1411.01 stable release

* Mon Oct 27 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1410.00-4
- rebuilt

* Mon Oct 27 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1410.00-3
- Remove unnecessary files.

* Sat Oct 25 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1410.00-2
- Bump to 1410.00-2, typo for getent

* Sat Oct 25 2014 Ye Myat Kaung <mavjs01@gmail.com> = 1410.00-1
- Package version bumped to 1410.00 since it's the latest stable release.

* Wed Oct 01 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-4
- Default flag in cmake macro causing libjthread.so errors.
- Turned off with -DBUILD_SHARED_LIBS:BOOL=OFF

* Thu Sep 25 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-3
- Packaged both server and client.
- This got rid of -DBUILD_SERVER=0

* Sat Sep 20 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-2
- Make changes according to review

* Thu Sep 11 2014 Ye Myat Kaung <mavjs01@gmail.com> - 1409.00-1
- Initial package of voxelands 1409.00 for Fedora repos.
